@@ -639,7 +639,7 @@ class copyTest(MayBeDiskTest):
 
     def tearDown(self):
         # Restore defaults
-        bcolz.cparams.setdefaults(clevel=5, shuffle=True, cname='blosclz')
+        bcolz.cparams.setdefaults(clevel=5, shuffle=bcolz.SHUFFLE, cname='blosclz')
         MayBeDiskTest.tearDown(self)
 
     def test00(self):
@@ -675,7 +675,7 @@ class copyTest(MayBeDiskTest):
         a = np.linspace(-1., 1., self.N)
         b = bcolz.carray(a, rootdir=self.rootdir)
         bcolz.cparams.setdefaults(clevel=1)
-        c = b.copy(cparams=bcolz.cparams(shuffle=False))
+        c = b.copy(cparams=bcolz.cparams(shuffle=bcolz.NOSHUFFLE))
         # print "b.cbytes, c.cbytes:", b.cbytes, c.cbytes
         self.assertTrue(b.cbytes < c.cbytes, "shuffle not changed")
 
@@ -683,7 +683,7 @@ class copyTest(MayBeDiskTest):
         """Testing copy() with no shuffle (setdefaults version)"""
         a = np.linspace(-1., 1., self.N)
         b = bcolz.carray(a, rootdir=self.rootdir)
-        bcolz.cparams.setdefaults(shuffle=False)
+        bcolz.cparams.setdefaults(shuffle=bcolz.NOSHUFFLE)
         c = b.copy()
         # print "b.cbytes, c.cbytes:", b.cbytes, c.cbytes
         self.assertTrue(b.cbytes < c.cbytes, "shuffle not changed")
@@ -1294,7 +1294,7 @@ class fancy_indexing_getitemTest(TestCase):
         a = np.arange(1, 101)
         b = bcolz.carray(a)
         c = b[[1.1, 3.3]]
-        r = a[[1.1, 3.3]]
+        r = a[[1, 3]]
         assert_array_equal(c, r, "fancy indexing does not work correctly")
 
     def test04(self):
@@ -1590,7 +1590,7 @@ class evalTest(MayBeDiskTest):
         nr = np.sin(a) + 2 * np.log(b) - 3
         # print "bcolz.eval ->", cr
         # print "numpy   ->", nr
-        assert_array_equal(cr[:], nr, "eval does not work correctly")
+        assert_allclose(cr[:], nr, err_msg="eval does not work correctly")
 
     def test12(self):
         """Testing eval() with `out_flavor` == 'numpy'"""
@@ -1603,47 +1603,63 @@ class evalTest(MayBeDiskTest):
         self.assertTrue(type(cr) == np.ndarray)
         assert_array_equal(cr, nr, "eval does not work correctly")
 
+    def test13(self):
+        """Testing eval() with columnar [shape = (n, 1)] arrays"""
+        a = bcolz.ones((self.N, 1))
+        b = bcolz.zeros(a.shape)
+        b = bcolz.eval('a + b')
+        self.assertEqual(b.sum(), self.N)
 
-class evalSmall(evalTest):
+class evalSmall(evalTest, TestCase):
     N = 10
 
 
-class evalDiskSmall(evalTest):
+class evalDiskSmall(evalTest, TestCase):
     N = 10
     disk = True
 
 
-class evalBig(evalTest):
+class evalBig(evalTest, TestCase):
     N = 1e4
 
 
-class evalDiskBig(evalTest):
+class evalDiskBig(evalTest, TestCase):
     N = 1e4
     disk = True
 
 
-class evalSmallNE(evalTest):
+@skipUnless(bcolz.numexpr_here, 'Needs numexpr')
+class evalSmallNE(evalTest, TestCase):
     N = 10
     vm = "numexpr"
 
 
-class evalDiskSmallNE(evalTest):
+@skipUnless(bcolz.numexpr_here, 'Needs numexpr')
+class evalDiskSmallNE(evalTest, TestCase):
     N = 10
     vm = "numexpr"
     disk = True
 
 
-class evalBigNE(evalTest):
+@skipUnless(bcolz.numexpr_here, 'Needs numexpr')
+class evalBigNE(evalTest, TestCase):
     N = 1e4
     vm = "numexpr"
 
 
-class evalDiskBigNE(evalTest):
+@skipUnless(bcolz.numexpr_here, 'Needs numexpr')
+class evalDiskBigNE(evalTest, TestCase):
     N = 1e4
     vm = "numexpr"
     disk = True
 
 
+@skipUnless(bcolz.numexpr_here and common.heavy, "Needs numexpr and --heavy")
+class evalVeryBigNE(evalTest, TestCase):
+    N = int(1e7)
+    vm = "numexpr"
+
+
 class computeMethodsTest(TestCase):
 
     def test00(self):
@@ -2067,7 +2083,7 @@ class bloscCompressorsTest(MayBeDiskTest, TestCase):
 
     def tearDown(self):
         # Restore defaults
-        bcolz.cparams.setdefaults(clevel=5, shuffle=True, cname='blosclz')
+        bcolz.cparams.setdefaults(clevel=5, shuffle=bcolz.SHUFFLE, cname='blosclz')
         MayBeDiskTest.tearDown(self)
 
     def test00(self):
@@ -2115,7 +2131,7 @@ class bloscCompressorsTest(MayBeDiskTest, TestCase):
         # print "\nsize b uncompressed-->", a.size * a.dtype.itemsize
         for cname in cnames:
             bcolz.defaults.cparams = {
-                'clevel': 9, 'shuffle': True, 'cname': cname}
+                'clevel': 9, 'shuffle': bcolz.SHUFFLE, 'cname': cname}
             b = bcolz.carray(a, rootdir=self.rootdir)
             # print "size b compressed  -->", b.cbytes, "with '%s'"%cname
             self.assertTrue(sys.getsizeof(b) < b.nbytes,
@@ -2126,7 +2142,7 @@ class bloscCompressorsTest(MayBeDiskTest, TestCase):
                 common.remove_tree(self.rootdir)
         # Restore defaults
         bcolz.defaults.cparams = {
-            'clevel': 5, 'shuffle': True, 'cname': 'blosclz'}
+            'clevel': 5, 'shuffle': bcolz.SHUFFLE, 'cname': 'blosclz'}
 
 
 class compressorsMemoryTest(bloscCompressorsTest, TestCase):
@@ -2137,6 +2153,81 @@ class compressorsDiskTest(bloscCompressorsTest, TestCase):
     disk = True
 
 
+class bloscFiltersTest(MayBeDiskTest, TestCase):
+
+    def tearDown(self):
+        # Restore defaults
+        bcolz.cparams.setdefaults(clevel=5, shuffle=bcolz.SHUFFLE,
+                                  cname='blosclz')
+        MayBeDiskTest.tearDown(self)
+
+    def test00(self):
+        """Testing all available filters in small arrays"""
+        a = np.arange(20)
+        filters = bcolz.filters.keys()
+        if common.verbose:
+            print("Checking filters:", filters)
+        # print "\nsize b uncompressed-->", a.size * a.dtype.itemsize
+        for filter_ in filters:
+            b = bcolz.carray(a, rootdir=self.rootdir,
+                             cparams=bcolz.cparams(clevel=9, shuffle=filter_))
+            # print "size b compressed  -->", b.cbytes, "with '%s'"%cname
+            self.assertTrue(sys.getsizeof(b) > b.nbytes,
+                            "compression does not seem to have any overhead")
+            assert_array_equal(a, b[:], "Arrays are not equal")
+            # Remove the array on disk before trying with the next one
+            if self.disk:
+                common.remove_tree(self.rootdir)
+
+    def test01a(self):
+        """Testing all available filters in big arrays (setdefaults)"""
+        a = np.arange(1e5)
+        filters = bcolz.filters.keys()
+        if common.verbose:
+            print("Checking compressors:", cnames)
+        # print "\nsize b uncompressed-->", a.size * a.dtype.itemsize
+        for filter_ in filters:
+            bcolz.cparams.setdefaults(clevel=9, shuffle=filter_)
+            b = bcolz.carray(a, rootdir=self.rootdir)
+            # print "size b compressed  -->", b.cbytes, "with '%s'"%cname
+            self.assertTrue(sys.getsizeof(b) < b.nbytes,
+                            "carray does not seem to compress at all")
+            assert_array_equal(a, b[:], "Arrays are not equal")
+            # Remove the array on disk before trying with the next one
+            if self.disk:
+                common.remove_tree(self.rootdir)
+
+    def test01b(self):
+        """Testing all available filters in big arrays (bcolz.defaults)"""
+        a = np.arange(1e5)
+        filters = bcolz.filters.keys()
+        if common.verbose:
+            print("Checking compressors:", cnames)
+        # print "\nsize b uncompressed-->", a.size * a.dtype.itemsize
+        for filter_ in filters:
+            bcolz.defaults.cparams = {
+                'clevel': 9, 'shuffle': filter_, 'cname': "blosclz"}
+            b = bcolz.carray(a, rootdir=self.rootdir)
+            # print "size b compressed  -->", b.cbytes, "with '%s'"%cname
+            self.assertTrue(sys.getsizeof(b) < b.nbytes,
+                            "carray does not seem to compress at all")
+            assert_array_equal(a, b[:], "Arrays are not equal")
+            # Remove the array on disk before trying with the next one
+            if self.disk:
+                common.remove_tree(self.rootdir)
+        # Restore defaults
+        bcolz.defaults.cparams = {
+            'clevel': 5, 'shuffle': bcolz.SHUFFLE, 'cname': 'blosclz'}
+
+
+class filtersMemoryTest(bloscFiltersTest, TestCase):
+    disk = False
+
+
+class filtersDiskTest(bloscFiltersTest, TestCase):
+    disk = True
+
+
 class reprTest(TestCase):
     def test_datetime_carray_day(self):
         ct = carray(np.array(['2010-01-01', '2010-01-02'],
@@ -2144,6 +2235,7 @@ class reprTest(TestCase):
         result = repr(ct)
         self.assertTrue("['2010-01-01' '2010-01-02']" in result)
 
+    @unittest.skipIf(os.name == "nt", "Windows problems with TZ here")
     def test_datetime_carray_nanos(self):
         x = ['2014-12-29T17:57:59.000000123',
              '2014-12-29T17:57:59.000000456']
@@ -2181,7 +2273,7 @@ class reprDiskTest(MayBeDiskTest,TestCase):
         expected = textwrap.dedent("""
                    carray((0,), float64)
                      nbytes: 0; cbytes: 16.00 KB; ratio: 0.00
-                     cparams := cparams(clevel=5, shuffle=True, cname='blosclz')
+                     cparams := cparams(clevel=5, shuffle=1, cname='blosclz')
                      rootdir := '%s'
                      mode    := '%s'
                    []
