@@ -132,7 +132,7 @@ class createTest(MayBeDiskTest):
         N = 0
         dtype = "i4,i8,f8"
         ra = np.zeros(N, dtype=dtype)
-        cparams = bcolz.cparams(clevel=9, shuffle=False)
+        cparams = bcolz.cparams(clevel=9, shuffle=bcolz.NOSHUFFLE)
         ct = bcolz.zeros(N, dtype=dtype, cparams=cparams, rootdir=self.rootdir)
         assert_array_equal(ct[:], ra, "ctable values are not correct")
         self.assertEqual(cparams, ct.cparams)
@@ -169,7 +169,7 @@ class createTest(MayBeDiskTest):
         N = 10000
         dtype = "i4,i8,f8"
         ra = np.zeros(N, dtype=dtype)
-        cparams = bcolz.cparams(clevel=9, shuffle=False)
+        cparams = bcolz.cparams(clevel=9, shuffle=bcolz.NOSHUFFLE)
         ct = bcolz.zeros(N, dtype=dtype, cparams=cparams, rootdir=self.rootdir)
         assert_array_equal(ct[:], ra, "ctable values are not correct")
         self.assertEqual(cparams, ct.cparams)
@@ -452,6 +452,28 @@ class add_del_colTest(MayBeDiskTest):
         # print "ra[:]", ra[:]
         assert_array_equal(t[:], ra, "ctable values are not correct")
 
+    def test09a(self):
+        """Testing overwriting an existing column (using __setitem__)"""
+        N = 10
+        ra = np.fromiter(((i, i * 3, i * 2.)
+                          for i in xrange(N)), dtype='i4,i8,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        t['f1'] = np.arange(N, dtype='i8')
+        ra = np.fromiter(((i, i, i * 2.) for i in xrange(N)),
+                          dtype='i4,i8,f8')
+        ra.dtype.names = ('f0', 'f1', 'f2')
+        # print "t->", `t`
+        # print "ra[:]", ra[:]
+        assert_array_equal(t[:], ra, "ctable values are not correct")
+
+    def test09b(self):
+        """Testing overwriting an existing column (different length)"""
+        N = 10
+        ra = np.fromiter(((i, i * 3, i * 2.)
+                          for i in xrange(N)), dtype='i4,i8,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        self.assertRaises(ValueError, t.__setitem__,
+                          'f1', np.arange(N + 1, dtype='i8'))
 
 class add_del_colMemoryTest(add_del_colTest, TestCase):
     disk = False
@@ -937,7 +959,8 @@ class copyTest(MayBeDiskTest):
         ra = np.fromiter(((i, i ** 2.2) for i in xrange(N)), dtype='i4,f8')
         t = bcolz.ctable(ra)
         # print "t:", repr(t), t.rootdir
-        t2 = t.copy(cparams=bcolz.cparams(shuffle=False), rootdir=self.rootdir)
+        t2 = t.copy(cparams=bcolz.cparams(shuffle=bcolz.NOSHUFFLE),
+                    rootdir=self.rootdir)
         # print "cbytes in f1, f2:", t['f1'].cbytes, t2['f1'].cbytes
         self.assertTrue(t['f1'].cbytes < t2['f1'].cbytes, "clevel not changed")
 
@@ -1174,7 +1197,7 @@ class fancy_indexing_getitemTest(TestCase):
                           for i in xrange(N)), dtype='i4,f8,i8')
         t = bcolz.ctable(ra)
         rt = t[[2.3, 5.6]]
-        rar = ra[[2.3, 5.6]]
+        rar = ra[[2, 5]]
         # print "rt->", rt
         # print "rar->", rar
         assert_array_equal(rt, rar, "ctable values are not correct")
